import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleCloudforceOneRequestPriority = cloudflare.getCloudforceOneRequestPriority({
 *     accountIdentifier: "023e105f4ecef8ad9ca31a8372d0c353",
 *     priorityIdentifer: "f174e90a-fafe-4643-bbbc-4a0ed4fc8415",
 * });
 * ```
 */
export declare function getCloudforceOneRequestPriority(args: GetCloudforceOneRequestPriorityArgs, opts?: pulumi.InvokeOptions): Promise<GetCloudforceOneRequestPriorityResult>;
/**
 * A collection of arguments for invoking getCloudforceOneRequestPriority.
 */
export interface GetCloudforceOneRequestPriorityArgs {
    /**
     * Identifier
     */
    accountIdentifier: string;
    /**
     * UUID
     */
    priorityIdentifer: string;
}
/**
 * A collection of values returned by getCloudforceOneRequestPriority.
 */
export interface GetCloudforceOneRequestPriorityResult {
    /**
     * Identifier
     */
    readonly accountIdentifier: string;
    readonly completed: string;
    /**
     * Request content
     */
    readonly content: string;
    readonly created: string;
    /**
     * UUID
     */
    readonly id: string;
    /**
     * Tokens for the request messages
     */
    readonly messageTokens: number;
    readonly priority: string;
    /**
     * UUID
     */
    readonly priorityIdentifer: string;
    /**
     * Readable Request ID
     */
    readonly readableId: string;
    /**
     * Requested information from request
     */
    readonly request: string;
    /**
     * Request Status
     * Available values: "open", "accepted", "reported", "approved", "completed", "declined".
     */
    readonly status: string;
    /**
     * Brief description of the request
     */
    readonly summary: string;
    /**
     * The CISA defined Traffic Light Protocol (TLP)
     * Available values: "clear", "amber", "amber-strict", "green", "red".
     */
    readonly tlp: string;
    /**
     * Tokens for the request
     */
    readonly tokens: number;
    readonly updated: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleCloudforceOneRequestPriority = cloudflare.getCloudforceOneRequestPriority({
 *     accountIdentifier: "023e105f4ecef8ad9ca31a8372d0c353",
 *     priorityIdentifer: "f174e90a-fafe-4643-bbbc-4a0ed4fc8415",
 * });
 * ```
 */
export declare function getCloudforceOneRequestPriorityOutput(args: GetCloudforceOneRequestPriorityOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCloudforceOneRequestPriorityResult>;
/**
 * A collection of arguments for invoking getCloudforceOneRequestPriority.
 */
export interface GetCloudforceOneRequestPriorityOutputArgs {
    /**
     * Identifier
     */
    accountIdentifier: pulumi.Input<string>;
    /**
     * UUID
     */
    priorityIdentifer: pulumi.Input<string>;
}
