import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleR2BucketEventNotification = cloudflare.getR2BucketEventNotification({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     bucketName: "example-bucket",
 * });
 * ```
 */
export declare function getR2BucketEventNotification(args: GetR2BucketEventNotificationArgs, opts?: pulumi.InvokeOptions): Promise<GetR2BucketEventNotificationResult>;
/**
 * A collection of arguments for invoking getR2BucketEventNotification.
 */
export interface GetR2BucketEventNotificationArgs {
    /**
     * Account ID.
     */
    accountId: string;
    /**
     * Name of the bucket.
     */
    bucketName: string;
}
/**
 * A collection of values returned by getR2BucketEventNotification.
 */
export interface GetR2BucketEventNotificationResult {
    /**
     * Account ID.
     */
    readonly accountId: string;
    /**
     * Name of the bucket.
     */
    readonly bucketName: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * List of queues associated with the bucket.
     */
    readonly queues: outputs.GetR2BucketEventNotificationQueue[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleR2BucketEventNotification = cloudflare.getR2BucketEventNotification({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     bucketName: "example-bucket",
 * });
 * ```
 */
export declare function getR2BucketEventNotificationOutput(args: GetR2BucketEventNotificationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetR2BucketEventNotificationResult>;
/**
 * A collection of arguments for invoking getR2BucketEventNotification.
 */
export interface GetR2BucketEventNotificationOutputArgs {
    /**
     * Account ID.
     */
    accountId: pulumi.Input<string>;
    /**
     * Name of the bucket.
     */
    bucketName: pulumi.Input<string>;
}
